@@ -639,9 +639,10 @@ users_received_cb (GObject      *source_object,
       JsonObject *obj = json_array_get_object_element (root_arr, i);
 
       data->ids[i].id = json_object_get_int_member (obj, "id");
-      data->ids[i].user_name = cb_utils_escape_ampersands (json_object_get_string_member (obj, "name"));
+      data->ids[i].user_name = g_strdup (json_object_get_string_member (obj, "name"));
       data->ids[i].screen_name = g_strdup (json_object_get_string_member (obj, "screen_name"));
       data->ids[i].verified = json_object_get_boolean_member (obj, "verified");
+      data->ids[i].protected_account = json_object_get_boolean_member (obj, "protected");
     }
 
   json_node_unref (root_node);
